package com.muyu.mysql;

import com.muyu.mysql.confilg.MySqlConfilg;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;

/**
 * mysql连接信息 MysqlConnectionInformation
 *
 * @author LeYang
 * on 2024/5/10
 */
public class MysqlConnectionInformation implements MySqlConnect<Connection> {
    /**
     * 打印日志
     */
    private static final Logger log = LoggerFactory.getLogger(MysqlConnectionInformation.class);

    public MySqlConfilg mySqlConfilg;

    public  MysqlConnectionInformation(MySqlConfilg mySqlConfilg) {
        this.mySqlConfilg = mySqlConfilg;
        MySqlConfig.dirver(this.mySqlConfilg.getDriverName());
    }



    @Override
    public Connection getConn(MySqlConfilg mySqlConfig) {
       this.mySqlConfilg = mySqlConfig;
        String url = this.mySqlConfilg.getUrl();
        String password = this.mySqlConfilg.getPassword();
        String name = this.mySqlConfilg.getName();
        Connection connection = null;
        try {
            connection = DriverManager.getConnection(url, name, password);
            if (connection != null) {
                log.info("获取数据库连接成功");
            }
        } catch (SQLException e) {
            log.error("获取数据库连接失败");
            throw new RuntimeException(e);
        }

        return connection;
    }

    @Override
    public void closeConn() {
        this.close();
    }

    //关闭连接
    public void  close(){

        Connection conn = this.getConn(this.mySqlConfilg);
        try {
            conn.close();
            log.info("关闭连接");
        } catch (SQLException e) {
            log.error("关闭连接失败");
            throw new RuntimeException(e);
        }
    }
}
