package com.muyu.kvt.client.config;

import com.muyu.common.core.domain.Result;
import com.muyu.kvt.client.pool.BasePool;
import com.muyu.kvt.client.pool.MysqlPool;
import com.muyu.kvt.client.pool.confilg.MysqlPoolConfig;
import com.muyu.kvt.client.pool.dto.SysDataSource;
import com.muyu.kvt.domain.Kvt;
import com.muyu.kvt.remote.RemoteDataManagerService;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;

import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/**
 * 初始化加载 KvtCilentRunner
 *
 * @author LeYang
 * on 2024/5/8
 */
@Log4j2
public class KvtClientRunner implements ApplicationRunner {

    @Autowired
    private RemoteDataManagerService remoteDataManagerService;


    static HashMap<String, Connection> map = new HashMap<>();

    @Override
    public void run(ApplicationArguments args) throws Exception {

        List<SysDataSource> list = new ArrayList<>();
        Result<List<Kvt>> listResult = remoteDataManagerService.selectKvt();
        List<Kvt> data = listResult.getData();
        HashMap<String, Object> hashMap = new HashMap<>();

        data.forEach(kvt -> {

                    MysqlPoolConfig build = MysqlPoolConfig.builder()
                            .id(String.valueOf(kvt.getId()))
                            .ip(kvt.getHost())
                            .port(kvt.getPort())
                            .databaseName(kvt.getDatabaseName())
                            .param(kvt.getConnectionParam())
                            .initTotal(Math.toIntExact(kvt.getInitNum()))
                            .maxTotal(Math.toIntExact(kvt.getMaxNum()))
                            .maxWaitTimes(kvt.getMaxWaitTime())
                            .userName(kvt.getUsername())
                            .password(kvt.getPassword())
                            .driverName("com.mysql.cj.jdbc.Driver")
                            .build();
                    BasePool<Connection> mysqlPool = new MysqlPool(build);

            log.info("初始化开始");

            mysqlPool.init();
            int initNum = build.getInitTotal();
            for (int i = 0; i < initNum; i++) {
                Connection connection = mysqlPool.creatConnection();
                map.put(String.valueOf(i), connection);
                mysqlPool.returnConn(connection);
            }
            log.info("-------------------------");
            mysqlPool.close();
            log.info("map:{}",map);
                });
        Connection connection = map.get("1");
        Statement statement =null;
        try{
            statement = connection.createStatement();
            ResultSet resultSet = statement.executeQuery("SHOW Tables");
            while (resultSet.next()){
                String name = resultSet.getString(1);
                log.info("name:{}",name);
            }
            log.info("连接成功");
        }catch (SQLException e){
            log.error("sql错误");
        }


//        SysDataSource sysDataSource = new SysDataSource();
//        sysDataSource.setId("1");
//        sysDataSource.setName("本地数据库");
//        sysDataSource.setSystemName("localhost");
//        sysDataSource.setHost("127.0.0.1");
//        sysDataSource.setPort("3306");
//        sysDataSource.setUsername("root");
//        sysDataSource.setPassword("root");
//        sysDataSource.setType("MySql");
//        sysDataSource.setDatabaseName("damo01");
//        sysDataSource.setConnectionParam("useUnicode=true&characterEncoding=utf8&allowMultiQueries=true");
//        sysDataSource.setInitNum(5);
//        sysDataSource.setMaxNum(10);
//        sysDataSource.setMaxWaitTime(4);
//        sysDataSource.setMaxWaitSize(3);
//        sysDataSource.setRemark("测试");
//        sysDataSource.setIsInit("Y");
//
//        list.add(sysDataSource);
//
//        list.forEach(sysDataSoure -> {
//            MysqlPoolConfig build = MysqlPoolConfig.builder()
//                    .id(sysDataSoure.getId())
//                    .ip(sysDataSoure.getHost())
//                    .port(sysDataSoure.getPort())
//                    .databaseName(sysDataSoure.getDatabaseName())
//                    .param(sysDataSoure.getConnectionParam())
//                    .initTotal(sysDataSoure.getInitNum())
//                    .maxTotal(sysDataSoure.getMaxNum())
//                    .maxWaitTimes(sysDataSoure.getMaxWaitTime())
//                    .userName(sysDataSoure.getUsername())
//                    .password(sysDataSoure.getPassword())
//                    .driverName("com.mysql.cj.jdbc.Driver")
//                    .build();
//            BasePool<Connection> mysqlPool = new MysqlPool(build);
//
//            log.info("初始化开始");
//
//            mysqlPool.init();
//            int initNum = sysDataSoure.getInitNum();
//            for (int i = 0; i < initNum; i++) {
//                Connection connection = mysqlPool.creatConnection();
//                map.put(String.valueOf(i), connection);
//                mysqlPool.returnConn(connection);
//            }
//            log.info("-------------------------");
//            mysqlPool.close();
//            log.info("map:{}",map);
//        });

//        Connection connection = map.get("1");
//        Statement statement =null;
//        try{
//            statement = connection.createStatement();
//            ResultSet resultSet = statement.executeQuery("select * from user");
//            while (resultSet.next()){
//                int id = resultSet.getInt(1);
//                String name = resultSet.getString(2);
//                log.info("id:{},name:{}",id,name);
//            }
//            log.info("连接成功");
//        }catch (SQLException e){
//            log.error("sql错误");
//        }


//        DruidDataSource dataSource = new DruidDataSource();
//        dataSource.setUsername("root");
//        dataSource.setPassword("wxl@123");
//        dataSource.setUrl("jdbc:mysql://111.229.37.54:3306/rule_engine?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8");
//        dataSource.setDriverClassName("com.mysql.cj.jdbc.Driver");
//        // 连接池最小空闲的连接数
//        dataSource.setMinIdle(5);
//        // 连接池最大活跃的连接数
//        dataSource.setMaxActive(20);
//        // 初始化连接池时创建的连接数
//        dataSource.setInitialSize(10);
//        MysqlPool mysqlPool = new MysqlPool();
//            mysqlPool.init();
//        try {
//            dataSource.init();
//        } catch (SQLException e) {
//            throw new RuntimeException(e);
//        }
//        System.out.println(dataSource);
    }
//    @Configuration
//    class DataSourceConfig{
//        @Bean
//        public DataSource dataSource(){
//
//        }
//    }

}
